@@ -777,6 +777,11 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :font-weight 500)
             `(a
               :color ,theme:primary)
+            `(dt
+              :font-weight bold)
+            `(dd
+              :margin-inline-start 1em
+              :font-size xx-small)
             `((:and a :hover)
               :cursor "pointer"
               :text-decoration "underline")
@@ -803,30 +808,30 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :border-radius "2px"
               :padding "6px"
               :margin "2px")
-	    `(.action
+	        `(.action
               :color ,theme:action)
-	    `(.button.action
+	        `(.button.action
               :background-color ,theme:action
               :color ,theme:on-action
               :border-color ,theme:action+)
             `(.warning
               :color ,theme:warning)
-	    `(.button.warning
-	      :background-color ,theme:warning
-	      :color ,theme:on-warning
-	      :border-color ,theme:warning+)
+	        `(.button.warning
+	          :background-color ,theme:warning
+	          :color ,theme:on-warning
+	          :border-color ,theme:warning+)
             `(.success
               :color ,theme:success)
-	    `(.button.success
-               :background-color ,theme:success
-               :color ,theme:on-success
-               :border-color ,theme:success+)
+	        `(.button.success
+              :background-color ,theme:success
+              :color ,theme:on-success
+              :border-color ,theme:success+)
             `(.highlight
               :color ,theme:highlight)
-	    `(.button.highlight
-	      :background-color ,theme:highlight
-	      :color ,theme:on-highlight
-	      :border-color ,theme:highlight+)
+	        `(.button.highlight
+	          :background-color ,theme:highlight
+	          :color ,theme:on-highlight
+	          :border-color ,theme:highlight+)
             `((:and .button :hover)
               :cursor "pointer"
               :opacity 0.8)
