@@ -891,3 +891,20 @@ Nyxt version exists.  It is only raised when the major version differs.")
      (:li "Fix accepted values of "
           (:nxref :class-name 'browser :slot 'external-editor-program)
           "."))))
+
+(define-version "3.9.1"
+  (:nsection :title "UI/UX"
+    (:ul
+     (:li "UI improvement of interfaces bound to commands "
+          (:nxref :command 'nyxt/mode/bookmark:bookmarks-panel) ", "
+          (:nxref :command 'nyxt/mode/bookmark:list-bookmarks) " and "
+          (:nxref :command 'nyxt/mode/buffer-listing:buffers-panel) ".")))
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix command " (:nxref :command 'nyxt/mode/bookmark:bookmark-url) ".")
+     (:li "Fix commands that rely on "
+          (:nxref :class-name 'browser :slot 'external-editor-program)
+          ".")
+     (:li "Fix command "
+          (:nxref :command 'nyxt/mode/prompt-buffer:toggle-attributes-display)
+          " and behavior of UI elements relying on it."))))
