@@ -113,7 +113,7 @@ to the next."
           :background-color ,theme:background-
           :color ,theme:text-)))
     (:div.row
-     :style "height: 100%; margin: 0"
+     :style "min-height: 100%; margin: 0"
      (:div.tabs
       (:a.tab-button
        :class (when (equal section 'keybindings) "active")
@@ -454,7 +454,7 @@ The value is saved to clipboard."
         :display "flex"
         :flex-direction "row")
       `(.logo
-        :color ,theme:on-background
+        :color ,(if (theme:dark-p theme:theme) theme:action theme:on-background)
         :width "100px"
         :height "100px"
         :padding-top "3px"
