@@ -452,7 +452,9 @@ LISTING is the string to enrich, autogenerated from FORM on demand."
           (replace-symbol-occurences specials nil :style :span))
         (dolist (string linkable-strings)
           (setf listing (str:replace-all (%ncode-prini string package)
-                                         (%ncode-prini (nyxt:resolve-backtick-quote-links string package) package)
+                                         (nyxt:prini-to-string
+                                          (nyxt:resolve-backtick-quote-links string package)
+                                          :escape t :readably t :package package)
                                          listing)))))
     listing))
 
@@ -533,8 +535,8 @@ Most *-P arguments mandate whether to add the buttons for:
                       `(`((external-editor
                            "Open in external editor"
                            "Open the file this code comes from in external editor.")
-                          (funcall (read-from-string "nyxt:launch-external-editor")
-                                   (uiop:native-namestring ,,file-var))))))))
+                          (funcall (read-from-string "nyxt/mode/file-manager:edit-file-with-external-editor")
+                                   (uiop:ensure-list ,,file-var))))))))
         (declare (ignorable keys))
         `(let* ((,body-var (list ,@body))
                 (,first (first ,body-var))
